==> haskell-errors-2.3.0-173.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 errors
version:              2.3.0
visibility:           public
id:                   errors-2.3.0-Af4PpDRSL7i9VMGNpLt601
key:                  errors-2.3.0-Af4PpDRSL7i9VMGNpLt601
license:              BSD-3-Clause
copyright:            2012, 2013 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Simplified error-handling
description:
    The one-stop shop for all your error-handling needs!  Just import
    "Control.Error".

    This library encourages an error-handling style that directly uses the type
    system, rather than out-of-band exceptions.

category:             Control, Error Handling
abi:                  3ec0ff378870604c7c8a045706e52d49
exposed:              True
exposed-modules:
    Control.Error Control.Error.Safe Control.Error.Script
    Control.Error.Util Data.EitherR

import-dirs:          /usr/lib/ghc-9.6.6/site-local/errors-2.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/errors-2.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/errors-2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-errors
hs-libraries:         HSerrors-2.3.0-Af4PpDRSL7i9VMGNpLt601
depends:
    base-4.18.2.1 exceptions-0.10.7 safe-0.3.21-6ywRAlXnRFuBscoqJeUz3o
    text-2.0.2 transformers-0.6.1.0
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH

haddock-interfaces:   /usr/share/doc/haskell-errors/html/errors.haddock
haddock-html:         /usr/share/doc/haskell-errors/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-errors-2.3.0-174-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 errors
version:              2.3.0
visibility:           public
id:                   errors-2.3.0-3AjakTf55HcGuIKwehvecj
key:                  errors-2.3.0-3AjakTf55HcGuIKwehvecj
license:              BSD-3-Clause
copyright:            2012, 2013 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Simplified error-handling
description:
    The one-stop shop for all your error-handling needs!  Just import
    "Control.Error".

    This library encourages an error-handling style that directly uses the type
    system, rather than out-of-band exceptions.

category:             Control, Error Handling
abi:                  04b731833e2e9523748e9624238a6827
exposed:              True
exposed-modules:
    Control.Error Control.Error.Safe Control.Error.Script
    Control.Error.Util Data.EitherR

import-dirs:          /usr/lib/ghc-9.6.6/site-local/errors-2.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/errors-2.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/errors-2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-errors
hs-libraries:         HSerrors-2.3.0-3AjakTf55HcGuIKwehvecj
depends:
    base-4.18.2.1 exceptions-0.10.7 safe-0.3.21-7oQO4KcgDWt1YhK3ifcAwa
    text-2.0.2 transformers-0.6.1.0
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH

haddock-interfaces:   /usr/share/doc/haskell-errors/html/errors.haddock
haddock-html:         /usr/share/doc/haskell-errors/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
